Python: module TileStache.Goodies.Providers.Cascadenik

TileStache.Goodies.Providers.Cascadenik | index

`Cascadenik Provider.
Simple wrapper for TileStache Mapnik provider that parses Cascadenik MML files
directly, skipping the typical compilation to XML step.
More information on Cascadenik:
- https://github.com/mapnik/Cascadenik/wiki/Cascadenik
Requires Cascadenik 2.x+.`

Classes
`` |  | TileStache.Mapnik.ImageProvider Provider
class Provider(TileStache.Mapnik.ImageProvider)
`` | `Renders map images from Cascadenik MML files. Arguments: - mapfile (required) Local file path to Mapnik XML file. - fonts (optional) Local directory path to *.ttf font files. - workdir (optional) Directory path for working files, tempfile.gettempdir() by default.`
| Methods defined here: __init__(self, layer, mapfile, fonts=None, workdir=None) `Initialize Cascadenik provider with layer and mapfile.` renderArea(self, width, height, srs, xmin, ymin, xmax, ymax, zoom) `Mostly hand off functionality to Mapnik.ImageProvider.renderArea()` Static methods inherited from TileStache.Mapnik.ImageProvider: prepareKeywordArgs(config_dict) `Convert configured parameters to keyword args for __init__().`